==> ejc-settlementmanage-impl-3.0.0-20230323.014022-192-sources.jar: com/ejianc/business/settlementmanage/vo/TurnoverLeaseSettlementVO.java <==
package com.ejianc.business.settlementmanage.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


/**
 * 周转租赁结算-主表
 * 
 * @author generator
 * 
 */
public class TurnoverLeaseSettlementVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String projectCode; // 项目编码
    private java.lang.String lessorName; // 租赁商名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private java.util.Date settlementDate; // 结算时间
    private java.lang.String settlementDateStr;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date billingStartTime; // 计费起始时间
    private java.lang.String billingStartTimeStr;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date billingEndTime; // 计费截止时间
    private java.lang.String billingEndTimeStr;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date date; // 日期
    private java.math.BigDecimal extaxCompensationSummary; // 赔偿金额汇总(除税)
    private java.math.BigDecimal intaxCompensationSummary; // 赔偿金额汇总(含税)
    private java.math.BigDecimal extaxMonthlyAmount; // 月度结算金额汇总(除税)
    private java.math.BigDecimal intaxMonthlyAmount; // 月度结算金额汇总(含税)
    private java.lang.String listingCode; // 清单编码
    private java.lang.String remarks; // 备注
    private java.lang.Long agentId; // 经办人
    private java.lang.String agentName; // 经办人名称
    private java.lang.Long agentDepartment; // 经办人部门
    private java.lang.String billStateStr; // 单据状态Str
    private java.math.BigDecimal extaxRepairSummary;// 修理费等其他费用汇总（除税）
    private java.math.BigDecimal intaxRepairSummary;// 修理费等其他费用汇总（含税）


    private List<TurnoverLeaseSetDetailVO> turnoverLeaseSetDetailEntities = new ArrayList<>(); // 周转租赁结算结算-子表

    public BigDecimal getExtaxRepairSummary() {
        return extaxRepairSummary;
    }

    public void setExtaxRepairSummary(BigDecimal extaxRepairSummary) {
        this.extaxRepairSummary = extaxRepairSummary;
    }

    public BigDecimal getIntaxRepairSummary() {
        return intaxRepairSummary;
    }

    public void setIntaxRepairSummary(BigDecimal intaxRepairSummary) {
        this.intaxRepairSummary = intaxRepairSummary;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 项目编码
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编码
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 租赁商名称
     */
    public java.lang.String getLessorName() {
        return lessorName;
    }

    /**
     * 租赁商名称
     */
    public void setLessorName(java.lang.String lessorName) {
        this.lessorName = lessorName;
    }
    /**
     * 结算时间
     */
    public java.util.Date getSettlementDate() {
        return settlementDate;
    }

    /**
     * 结算时间
     */
    public void setSettlementDate(java.util.Date settlementDate) {
        this.settlementDate = settlementDate;
    }
    /**
     * 计费起始时间
     */
    public java.util.Date getBillingStartTime() {
        return billingStartTime;
    }

    /**
     * 计费起始时间
     */
    public void setBillingStartTime(java.util.Date billingStartTime) {
        this.billingStartTime = billingStartTime;
    }
    /**
     * 计费截止时间
     */
    public java.util.Date getBillingEndTime() {
        return billingEndTime;
    }

    /**
     * 计费截止时间
     */
    public void setBillingEndTime(java.util.Date billingEndTime) {
        this.billingEndTime = billingEndTime;
    }
    /**
     * 日期
     */
    public java.util.Date getDate() {
        return date;
    }

    /**
     * 日期
     */
    public void setDate(java.util.Date date) {
        this.date = date;
    }
    /**
     * 赔偿金额汇总(除税)
     */
    public java.math.BigDecimal getExtaxCompensationSummary() {
        return extaxCompensationSummary;
    }

    /**
     * 赔偿金额汇总(除税)
     */
    public void setExtaxCompensationSummary(java.math.BigDecimal extaxCompensationSummary) {
        this.extaxCompensationSummary = extaxCompensationSummary;
    }
    /**
     * 赔偿金额汇总(含税)
     */
    public java.math.BigDecimal getIntaxCompensationSummary() {
        return intaxCompensationSummary;
    }

    /**
     * 赔偿金额汇总(含税)
     */
    public void setIntaxCompensationSummary(java.math.BigDecimal intaxCompensationSummary) {
        this.intaxCompensationSummary = intaxCompensationSummary;
    }
    /**
     * 月度结算金额汇总(除税)
     */
    public java.math.BigDecimal getExtaxMonthlyAmount() {
        return extaxMonthlyAmount;
    }

    /**
     * 月度结算金额汇总(除税)
     */
    public void setExtaxMonthlyAmount(java.math.BigDecimal extaxMonthlyAmount) {
        this.extaxMonthlyAmount = extaxMonthlyAmount;
    }
    /**
     * 月度结算金额汇总(含税)
     */
    public java.math.BigDecimal getIntaxMonthlyAmount() {
        return intaxMonthlyAmount;
    }

    /**
     * 月度结算金额汇总(含税)
     */
    public void setIntaxMonthlyAmount(java.math.BigDecimal intaxMonthlyAmount) {
        this.intaxMonthlyAmount = intaxMonthlyAmount;
    }
    /**
     * 清单编码
     */
    public java.lang.String getListingCode() {
        return listingCode;
    }

    /**
     * 清单编码
     */
    public void setListingCode(java.lang.String listingCode) {
        this.listingCode = listingCode;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 经办人部门
     */
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getAgentDepartment() {
        return agentDepartment;
    }
    /**
     * 经办人部门
     */
    @ReferDeserialTransfer
    public void setAgentDepartment(Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }

    public List<TurnoverLeaseSetDetailVO> getTurnoverLeaseSetDetailEntities() {
        return turnoverLeaseSetDetailEntities;
    }

    public void setTurnoverLeaseSetDetailEntities(List<TurnoverLeaseSetDetailVO> turnoverLeaseSetDetailEntities) {
        this.turnoverLeaseSetDetailEntities = turnoverLeaseSetDetailEntities;
    }
    /**
     * 单据状态
     */
    public String getBillStateStr() {
        return billStateStr;
    }
    /**
     * 单据状态
     */
    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public String getSettlementDateStr() {
        return settlementDateStr;
    }

    public void setSettlementDateStr(String settlementDateStr) {
        this.settlementDateStr = settlementDateStr;
    }

    public String getBillingStartTimeStr() {
        return billingStartTimeStr;
    }

    public void setBillingStartTimeStr(String billingStartTimeStr) {
        this.billingStartTimeStr = billingStartTimeStr;
    }

    public String getBillingEndTimeStr() {
        return billingEndTimeStr;
    }

    public void setBillingEndTimeStr(String billingEndTimeStr) {
        this.billingEndTimeStr = billingEndTimeStr;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20250822.092935-320-sources.jar: com/ejianc/business/settlementmanage/vo/TurnoverLeaseSettlementVO.java <==
package com.ejianc.business.settlementmanage.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


/**
 * 周转租赁结算-主表
 *
 * @author generator
 *
 */
public class TurnoverLeaseSettlementVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String projectCode; // 项目编码
    private java.lang.String lessorName; // 租赁商名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private java.util.Date settlementDate; // 结算时间
    private java.lang.String settlementDateStr;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date billingStartTime; // 计费起始时间
    private java.lang.String billingStartTimeStr;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date billingEndTime; // 计费截止时间
    private java.lang.String billingEndTimeStr;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date date; // 日期
    private java.math.BigDecimal extaxCompensationSummary; // 赔偿金额汇总(除税)
    private java.math.BigDecimal intaxCompensationSummary; // 赔偿金额汇总(含税)
    private java.math.BigDecimal extaxMonthlyAmount; // 月度结算金额汇总(除税)
    private java.math.BigDecimal intaxMonthlyAmount; // 月度结算金额汇总(含税)
    private java.lang.String listingCode; // 清单编码
    private java.lang.String remarks; // 备注
    private java.lang.Long agentId; // 经办人
    private java.lang.String agentName; // 经办人名称
    private java.lang.Long agentDepartment; // 经办人部门
    private String agentDepartmentName; // 经办人部门名称
    private java.lang.String billStateStr; // 单据状态Str
    private java.math.BigDecimal extaxRepairSummary;// 修理费等其他费用汇总（除税）
    private java.math.BigDecimal intaxRepairSummary;// 修理费等其他费用汇总（含税）


    private List<TurnoverLeaseSetDetailVO> turnoverLeaseSetDetailEntities = new ArrayList<>(); // 周转租赁结算结算-子表

    public BigDecimal getExtaxRepairSummary() {
        return extaxRepairSummary;
    }

    public void setExtaxRepairSummary(BigDecimal extaxRepairSummary) {
        this.extaxRepairSummary = extaxRepairSummary;
    }

    public BigDecimal getIntaxRepairSummary() {
        return intaxRepairSummary;
    }

    public void setIntaxRepairSummary(BigDecimal intaxRepairSummary) {
        this.intaxRepairSummary = intaxRepairSummary;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 项目编码
     */
    public java.lang.String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编码
     */
    public void setProjectCode(java.lang.String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 租赁商名称
     */
    public java.lang.String getLessorName() {
        return lessorName;
    }

    /**
     * 租赁商名称
     */
    public void setLessorName(java.lang.String lessorName) {
        this.lessorName = lessorName;
    }
    /**
     * 结算时间
     */
    public java.util.Date getSettlementDate() {
        return settlementDate;
    }

    /**
     * 结算时间
     */
    public void setSettlementDate(java.util.Date settlementDate) {
        this.settlementDate = settlementDate;
    }
    /**
     * 计费起始时间
     */
    public java.util.Date getBillingStartTime() {
        return billingStartTime;
    }

    /**
     * 计费起始时间
     */
    public void setBillingStartTime(java.util.Date billingStartTime) {
        this.billingStartTime = billingStartTime;
    }
    /**
     * 计费截止时间
     */
    public java.util.Date getBillingEndTime() {
        return billingEndTime;
    }

    /**
     * 计费截止时间
     */
    public void setBillingEndTime(java.util.Date billingEndTime) {
        this.billingEndTime = billingEndTime;
    }
    /**
     * 日期
     */
    public java.util.Date getDate() {
        return date;
    }

    /**
     * 日期
     */
    public void setDate(java.util.Date date) {
        this.date = date;
    }
    /**
     * 赔偿金额汇总(除税)
     */
    public java.math.BigDecimal getExtaxCompensationSummary() {
        return extaxCompensationSummary;
    }

    /**
     * 赔偿金额汇总(除税)
     */
    public void setExtaxCompensationSummary(java.math.BigDecimal extaxCompensationSummary) {
        this.extaxCompensationSummary = extaxCompensationSummary;
    }
    /**
     * 赔偿金额汇总(含税)
     */
    public java.math.BigDecimal getIntaxCompensationSummary() {
        return intaxCompensationSummary;
    }

    /**
     * 赔偿金额汇总(含税)
     */
    public void setIntaxCompensationSummary(java.math.BigDecimal intaxCompensationSummary) {
        this.intaxCompensationSummary = intaxCompensationSummary;
    }
    /**
     * 月度结算金额汇总(除税)
     */
    public java.math.BigDecimal getExtaxMonthlyAmount() {
        return extaxMonthlyAmount;
    }

    /**
     * 月度结算金额汇总(除税)
     */
    public void setExtaxMonthlyAmount(java.math.BigDecimal extaxMonthlyAmount) {
        this.extaxMonthlyAmount = extaxMonthlyAmount;
    }
    /**
     * 月度结算金额汇总(含税)
     */
    public java.math.BigDecimal getIntaxMonthlyAmount() {
        return intaxMonthlyAmount;
    }

    /**
     * 月度结算金额汇总(含税)
     */
    public void setIntaxMonthlyAmount(java.math.BigDecimal intaxMonthlyAmount) {
        this.intaxMonthlyAmount = intaxMonthlyAmount;
    }
    /**
     * 清单编码
     */
    public java.lang.String getListingCode() {
        return listingCode;
    }

    /**
     * 清单编码
     */
    public void setListingCode(java.lang.String listingCode) {
        this.listingCode = listingCode;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 经办人部门
     */
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getAgentDepartment() {
        return agentDepartment;
    }
    /**
     * 经办人部门
     */
    @ReferDeserialTransfer
    public void setAgentDepartment(Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }

    public String getAgentDepartmentName() {
        return agentDepartmentName;
    }

    public void setAgentDepartmentName(String agentDepartmentName) {
        this.agentDepartmentName = agentDepartmentName;
    }

    public List<TurnoverLeaseSetDetailVO> getTurnoverLeaseSetDetailEntities() {
        return turnoverLeaseSetDetailEntities;
    }

    public void setTurnoverLeaseSetDetailEntities(List<TurnoverLeaseSetDetailVO> turnoverLeaseSetDetailEntities) {
        this.turnoverLeaseSetDetailEntities = turnoverLeaseSetDetailEntities;
    }
    /**
     * 单据状态
     */
    public String getBillStateStr() {
        return billStateStr;
    }
    /**
     * 单据状态
     */
    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public String getSettlementDateStr() {
        return settlementDateStr;
    }

    public void setSettlementDateStr(String settlementDateStr) {
        this.settlementDateStr = settlementDateStr;
    }

    public String getBillingStartTimeStr() {
        return billingStartTimeStr;
    }

    public void setBillingStartTimeStr(String billingStartTimeStr) {
        this.billingStartTimeStr = billingStartTimeStr;
    }

    public String getBillingEndTimeStr() {
        return billingEndTimeStr;
    }

    public void setBillingEndTimeStr(String billingEndTimeStr) {
        this.billingEndTimeStr = billingEndTimeStr;
    }
}
